Helper library for spec to encode and decode JSON objects based on specs
Helper library for spec to encode and decode JSON objects based on specs
(decode spec x)Decode a Clojure data structure based on a spec. This is a
no-op for most spec types instead of maps defined with s/keys.
In the latter case, keys defined in the spec only are kept and
translated to their expected shape.
Decode a Clojure data structure based on a spec. This is a no-op for most spec types instead of maps defined with `s/keys`. In the latter case, keys defined in the spec only are kept and translated to their expected shape.
(encode m)Encode a data structure for JSON serialization. All maps are translated to use unqualified snake case keys to provide optimum compatibility with standard practices
Encode a data structure for JSON serialization. All maps are translated to use unqualified snake case keys to provide optimum compatibility with standard practices
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |